(function(mui, window, document, undefined) {
	mui.init();
	var get = function(id) {
		return document.getElementById(id);
	};
	var qsa = function(sel) {
		return [].slice.call(document.querySelectorAll(sel));
	};
	var ui = {
		content: get('content'),
		contact_name: get('contact_name'),
		contact_phone: get('contact_phone'),
		imageList: get('imageList'),
		submit: get('submit')
	};
	ui.clearForm = function() {
		ui.content.value = '';
		ui.contact_name.value = '';
		ui.contact_phone.value = '';
		ui.imageList.innerHTML = '';
		ui.newPlaceholder();
	};
	ui.getFileInputArray = function() {
		return [].slice.call(ui.imageList.querySelectorAll('input[type="file"]'));
	};
	ui.getFileInputIdArray = function() {
		var fileInputArray = ui.getFileInputArray();
		var idArray = [];
		fileInputArray.forEach(function(fileInput) {
			if (fileInput.value != '') {
				idArray.push(fileInput.getAttribute('id'));
			}
		});
		return idArray;
	};
	var imageIndexIdNum = 0;
	ui.newPlaceholder = function() {
		var fileInputArray = ui.getFileInputArray();
		if (fileInputArray &&
			fileInputArray.length > 0 &&
			fileInputArray[fileInputArray.length - 1].parentNode.classList.contains('space')) {
			return;
		}
		imageIndexIdNum++;
		var placeholder = document.createElement('div');
		placeholder.setAttribute('class', 'image-item space');
		var closeButton = document.createElement('div');
		closeButton.setAttribute('class', 'image-close');
		closeButton.innerHTML = 'X';
		closeButton.addEventListener('click', function(event) { //删除图片
			event.stopPropagation();
			event.cancelBubble = true;
			setTimeout(function() {
				ui.imageList.removeChild(placeholder);
			}, 0);
			return false;
		}, false);
		var fileInput = document.createElement('input');
		fileInput.setAttribute('type', 'file');
		fileInput.setAttribute('accept', 'image/*');
		fileInput.setAttribute('id', 'image-' + imageIndexIdNum);
		fileInput.addEventListener('change', function(event) { //增加图片
			var file = fileInput.files[0];
			if (file) {
				if (file.type.startWith("image")) {
					plus.nativeUI.showWaiting(); //大图片编码比较慢，需要等待
					var reader = new window.FileReader();
					reader.onload = function() { //处理 android 4.1 兼容问题
						var base64 = reader.result.split(',')[1];
						var dataUrl = 'data:image/png;base64,' + base64;
						placeholder.style.backgroundImage = 'url(' + dataUrl + ')';
						plus.nativeUI.closeWaiting();
					}
					reader.readAsDataURL(file);
					placeholder.classList.remove('space');
					ui.newPlaceholder();
				} else {
					mui.toast("请选择图片类型文件上传");
				}
			}
		}, false);
		placeholder.appendChild(closeButton);
		placeholder.appendChild(fileInput);
		ui.imageList.appendChild(placeholder);
	};
	ui.newPlaceholder();


	ui.submit.addEventListener('tap', function(event) {
		if (ui.content.value == '') {
			return mui.toast('请详细描述您的问题和意见');
		}
		plus.nativeUI.showWaiting();
		if (mui(".image-item").length > 1) { //包含图片
			uploadImage();
		} else {
			submitForm([]);
		}
	}, false);

	function uploadImage() {
		var item = mui(".image-item");
		var l = item.length;
		var base64 = [];
		for (var i = 0; i < l - 1; i++) {
			base64.push(item[i].style.background.replace("url(", "").replace(")", ""));
		}
		light.loadData("file.upload", {
				params: {
					server: light.nodejsServer + "/",
					str: base64,
					path: "feedback" //文件目录PostmanCard
				}
			}, function(result) {
				if (result.success) {
					var o = result.data;
					var img_url = [];
					for (var i in o.small_url) {
						img_url.push(o.small_url[i]);
					}
					submitForm(img_url);
				} else {
					plus.nativeUI.closeWaiting();
					mui.toast('提交图片失败');
				}
			},
			function() {
				plus.nativeUI.closeWaiting();
				mui.toast('提交图片失败');
			});
	}

	function submitForm(img_url) {
		light.loadData("service.UpdateData", {
			params: {
				id: 1394,
				param: {
					user_imsi: plus.os.name == 'Android' ? (plus.device.imsi || "-1") : "-1",
					content: ui.content.value,
					device_type: plus.os.name,
					user_terminal: plus.device.model || "-1",
					contact_name: ui.contact_name.value,
					contact_phone: ui.contact_phone.value,
					app_id: light.app_id,
					version_code: light.version_code,
					img_url: "{" + img_url.join() + "}"
				}
			}
		}, function(result) {
			plus.nativeUI.closeWaiting();
			if (result.success) {
				mui.toast("您的意见我们已经收到，感谢您对我们的支持与反馈！");
				mui.back();
			} else {
				mui.toast('提交反馈失败');
			}
		}, function() {
			plus.nativeUI.closeWaiting();
			mui.toast('提交反馈失败');
		});
	}

})(mui, window, document, undefined);